<?php

namespace App\Http\Controllers\Backend\Languages;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\Language;
use App\Models\Category;
use App\Models\Menu;
use App\Models\Page;
use App\Models\Product;
use App\Models\Slider;
use Helper;
use Illuminate\Support\Facades\Auth;
use Carbon\Carbon;
use File;
use Storage;
use Illuminate\Filesystem\Filesystem;


class LanguageController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
		$per_page = Helper::toInt($request["per-page"]);
		if($per_page<10){
			$per_page = 10;
		}
		
		if($request["search"]!=null){
			$search = $request["search"];
			return view('backend.languages.index')->with(['search' => $search ,'per_page' => $per_page ,'languages' => Language::where('title','like','%'.$search.'%')->paginate($per_page)]);
		}else{
			return view('backend.languages.index')->with(['search' => '' ,'per_page' => $per_page ,'languages' => Language::paginate($per_page)]);
		}
    }

/**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
	 
    public function edit($id)
    {
		$language = Language::find($id);
	
		if($language != null){
			return view('backend.languages.edit')->with(['language'=> $language]);
		}else{
			return redirect(route('languages.index'));
		}
    }
	
    public function change_variable(Request $request)
    {
		$code = $request["code"];
		$file = $request["file"];
		$key = $request["key"];
		$value = $request["value"];
		$lang_folder = base_path('lang') . '/' . $code;
		$lang = Helper::ReadLocaleFile($code,$file);
		if (strpos($key, '[') !== false) {
			$new_key = str_replace(']','',$key);
			$keys=explode('[',$new_key);
			$lang[$keys[0]][$keys[1]]=$value;
		}else{
			$lang[$key]=$value;
		}
		$result = Helper::var_export_short( $lang );
		file_put_contents($lang_folder . '/' . $file, '<?php '. "\n" . ' return '.$result.";\n" );
		
		return "success";
    }
	
    public function insert_variable(Request $request)
    {
		foreach(Helper::Locales() as $language_key => $language_value){
			$code = $language_key;
			$file = "system.php";
			$key = $request["key"];
			$value = $request["value"];
			$lang_folder = base_path('lang') . '/' . $code;
			$lang = Helper::ReadLocaleFile($code,$file);
			if (strpos($key, '[') !== false) {
				$new_key = str_replace(']','',$key);
				$keys=explode('[',$new_key);
				$lang[$keys[0]][$keys[1]]=$value;
			}else{
				$lang[$key]=$value;
			}
			$result = Helper::var_export_short( $lang );
			file_put_contents($lang_folder . '/' . $file, '<?php '. "\n" . ' return '.$result.";\n" );
		}
		
		return "success";
    }
	
    public function create(Request $request)
    {
		return view('backend.languages.create');
    }
	
    public function store(Request $request)
    {
		$lang_folder = base_path('lang');
		$code = $request['code'];
		if (file_exists($lang_folder . '/' . $code)) {
			return redirect(route('languages.create'))->with(['error'=>'Bu dil dosyası sistemde kayıtlıdır. Lütfen kontrol ediniz.']) ;
		}else{
			File::makeDirectory( $lang_folder . '/' . $code , 0777 , true );
			$default_language = Language::where('default',0)->first();
			
			copy( $lang_folder . '/'  . $default_language->code . '/' . 'auth.php'	, $lang_folder . '/' . $code . '/auth.php');
			copy( $lang_folder . '/'  . $default_language->code . '/' . 'pagination.php'	, $lang_folder . '/' . $code . '/pagination.php');
			copy( $lang_folder . '/'  . $default_language->code . '/' . 'passwords.php'	, $lang_folder . '/' . $code . '/passwords.php');
			copy( $lang_folder . '/'  . $default_language->code . '/' . 'system.php'	, $lang_folder . '/' . $code . '/system.php');
			copy( $lang_folder . '/'  . $default_language->code . '/' . 'validation.php'	, $lang_folder . '/' . $code . '/validation.php');
			
			$language = Language::create([
				'title' => $request['title'],
				'code' => $code,
				'default' => false,
				'status' => true,
			]);
			foreach( \App\Models\MenuCopy::where("locale",$default_language->code)->get() as $item){
				$new_item = $item->replicate();
				$new_item-> locale = $code;
				$new_item->	save();
			}
			foreach( \App\Models\CategoryCopy::where("locale",$default_language->code)->get() as $item){
				$new_item = $item->replicate();
				$new_item-> locale = $code;
				$new_item->	save();
			}
			foreach( \App\Models\ProductCopy::where("locale",$default_language->code)->get() as $item){
				$new_item = $item->replicate();
				$new_item-> locale = $code;
				$new_item->	save();
			}
			foreach( \App\Models\PageCopy::where("locale",$default_language->code)->get() as $item){
				$new_item = $item->replicate();
				$new_item-> locale = $code;
				$new_item->	save();
			}
			foreach( \App\Models\SliderCopy::where("locale",$default_language->code)->get() as $item){
				$new_item = $item->replicate();
				$new_item-> locale = $code;
				$new_item->	save();
			}
		   return redirect(route('languages.index'))->with(['success'=>'İşleminiz başarıyla tamamlanmıştır.']) ;
		}
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
		$lang = Language::find($id);
		$lang_folder = base_path('lang');
		$code = $request['code'];
		if($request["default"] == true){
			$affected = \DB::table('languages')->update(array('default' => 0));
		}
		if($code != $lang->code){
			if (file_exists($lang_folder . '/' . $code) ) {
				return redirect()->route('languages.edit',$id)->with('error','Bu dil dosyası sistemde kayıtlıdır. Lütfen kontrol ediniz.') ;
			}else{
				$menu = \DB::table('menu_translations')->where("locale",$lang->code)->update(array('locale' => $code));
				$categori = \DB::table('categorie_translations')->where("locale",$lang->code)->update(array('locale' => $code));
				$product = \DB::table('product_translations')->where("locale",$lang->code)->update(array('locale' => $code));
				$page = \DB::table('page_translations')->where("locale",$lang->code)->update(array('locale' => $code));
				$slider = \DB::table('slider_translations')->where("locale",$lang->code)->update(array('locale' => $code));
				rename( $lang_folder . '/' . $lang->code, $lang_folder . '/' . $code) ;
				 $lang->fill($request->all())->save();
				return redirect()->route('languages.edit',$id)->with('success','İşleminiz başarıyla tamamlanmıştır.') ;
			}
		}else{
			 $lang->fill($request->all())->save();
			return redirect()->route('languages.edit',$id)->with('success','İşleminiz başarıyla tamamlanmıştır.') ;
		}
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
		$lang_folder = base_path('lang');
		$language = Language::find($id);
		if($language){
			if($language->default == false){
				if (file_exists($lang_folder . '/' . $language->code)) {
					$file = new Filesystem;
					$file->cleanDirectory($lang_folder . '/' . $language->code);
					rmdir($lang_folder . '/' . $language->code);
				}
				\DB::table('menu_translations')->where("locale",$language->code)->delete();
				\DB::table('categorie_translations')->where("locale",$language->code)->delete();
				\DB::table('product_translations')->where("locale",$language->code)->delete();
				\DB::table('page_translations')->where("locale",$language->code)->delete();
				\DB::table('slider_translations')->where("locale",$language->code)->delete();
				$language->delete();
				 return redirect()->route('languages.index')->with('success','İşleminiz başarıyla tamamlanmıştır.');
			}else{
				return redirect()->route('languages.index')->with('error','Varsayılan dil silinemez!');
			}
		}
		 return redirect()->route('languages.index')->with('error','İşleminiz esnasında bir hata meydana geldi.');
    }
}
