<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\Frontend\Ajax\AjaxController;
use App\Http\Controllers\Frontend\Payment\PaymentController;
use App\Http\Controllers\Frontend\Login\LoginController;
use App\Http\Controllers\Auth\LoginController as BackendLoginController;
use App\Http\Controllers\Prints\PrintsController;
use App\Http\Controllers\Backend\HomeGetController;
use App\Http\Controllers\Backend\Files\FileManagementController;
use App\Http\Controllers\Backend\Files\FileController;
use App\Http\Controllers\Backend\Products\ProductController;
use App\Http\Controllers\Backend\Sms\SmsController;
use App\Http\Controllers\Backend\Adres\AdresController;
use App\Http\Controllers\Backend\Menus\MenusController;
use App\Http\Controllers\Backend\Siparis\SiparisController;
use App\Http\Controllers\Backend\Pages\PagesController;
use App\Http\Controllers\Backend\Sliders\SlidersController;
use App\Http\Controllers\Backend\Duyuru\DuyuruController;
use App\Http\Controllers\Backend\Mail\MailController;
use App\Http\Controllers\Backend\Users\UsersController;
use App\Http\Controllers\Backend\Bayi\BayiController;
use App\Http\Controllers\Backend\Customer\CustomerController;
use App\Http\Controllers\Backend\Settings\SettingsController;
use App\Http\Controllers\Backend\Languages\LanguageController;
use App\Http\Controllers\Frontend\Bayii\BayiController as FrontendBayiController;
use App\Http\Controllers\Frontend\Search\SearchController;
use App\Http\Controllers\Frontend\Content\ContentController;
use App\Http\Controllers\Frontend\Yorum\YorumController;

// Define your routes here
Route::post('ajax', [AjaxController::class, 'index'])->name("ajax-get");
Route::post('form-save', [AjaxController::class, 'store'])->name('form-save');
Route::post('payments', [PaymentController::class, 'index'])->name("payment");
Route::post('/success', [PaymentController::class, 'success'])->name("success");
Route::post('/failure', function (\Illuminate\Http\Request $request) {
    $request->session()->put('odeme', 1);
    $request->session()->put('adres', $request->adres);
    $request->session()->put('customer_id', $request->userId);
    return redirect('/odeme')->with('error', 'İşlem Sırasında hata meydana geldi');
});

Route::get('/admin/login', [BackendLoginController::class, 'showLoginForm'])->name("admin");
Route::post('/admin/login', [BackendLoginController::class, 'login']);
Route::get('/admin/logout', [BackendLoginController::class, 'logout'])->name("logout");
Route::get('print/{id}', [PrintsController::class, 'index']);

// File manager routes
Route::group(['prefix' => 'laravel-filemanager', 'middleware' => ['web', 'auth']], function () {
    \UniSharp\LaravelFilemanager\Lfm::routes();
});

// Admin routes
Route::prefix("admin")->middleware('auth')->group(function () {
    Route::get('/', [HomeGetController::class, 'index'])->name("index");
    Route::get('/files', [FileManagementController::class, 'getFiles'])->name("files");
    Route::get('/logout', [HomeGetController::class, 'getLogout'])->name("backend-logout");
    Route::post('/file-upload', [FileController::class, 'upload']);
    Route::post('/file-edit', [FileController::class, 'edit']);
    Route::post('/file-sort', [FileController::class, 'sort']);
    Route::post('/file-delete', [FileController::class, 'delete']);

    Route::prefix("products")->middleware('Admin')->group(function () {
        Route::get('/', [ProductController::class, 'getProducts'])->name("products");
        Route::get('/excel', [ProductController::class, 'getExcel'])->name("excel-add");
        Route::get('/product-add', [ProductController::class, 'getProductsAdd'])->name("product-add");
        Route::get('/product-edit/{productId}', [ProductController::class, 'getProductsEdit'])->name("product-edit");
        Route::get('/product-category', [ProductController::class, 'getProductsCategory'])->name("product-category");
        Route::get('/product-category-add', [ProductController::class, 'getProductsCategoryAdd'])->name("product-category-add");
        Route::get('/product-category-edit/{categoryId}', [ProductController::class, 'getProductsCategoryEdit'])->name("product-category-edit");
        Route::post('/excel', [ProductController::class, 'postExcel'])->name("excel-add");
        Route::post('/excel-update', [ProductController::class, 'postExcelUpdate'])->name("excel-update");
        Route::post('/excel-list', [ProductController::class, 'postExcelGet'])->name("excel-list");
        Route::post('/', [ProductController::class, 'postProducts'])->name("products");
        Route::post('/product-add', [ProductController::class, 'postProductsAdd'])->name("product-add");
        Route::post('/product-edit/{productId}', [ProductController::class, 'postProductsEdit'])->name("product-edit");
        Route::post('/product-category', [ProductController::class, 'postProductsCategory'])->name("product-category");
        Route::post('/product-category-add', [ProductController::class, 'postProductsCategoryAdd'])->name("product-category-add");
        Route::post('/product-category-edit/{categoryId}', [ProductController::class, 'postProductsCategoryEdit'])->name("product-category-edit");
    });

    Route::prefix("sms")->middleware('Admin')->group(function () {
        Route::get('/', [SmsController::class, 'getSms'])->name("sms");
        Route::get('/sms-add', [SmsController::class, 'getSmsAdd'])->name("sms-add");
        Route::post('/sms-add', [SmsController::class, 'postSmsAdd'])->name("sms-add");
        Route::get('/template', [SmsController::class, 'getSmsTemplate'])->name("sms-template");
        Route::get('/sms-template-edit/{smsId}', [SmsController::class, 'getSmsTemplateEdit'])->name("sms-template-edit");
        Route::get('/sms-template-add', [SmsController::class, 'getSmsTemplateAdd'])->name("sms-template-add");
        Route::post('/template', [SmsController::class, 'postSmsTemplate'])->name("sms-template");
        Route::post('/sms-template-edit/{smsId}', [SmsController::class, 'postSmsTemplateEdit'])->name("sms-template-edit");
        Route::post('/sms-template-add', [SmsController::class, 'postSmsTemplateAdd'])->name("sms-template-add");
        Route::get('/json-kullanici', [SmsController::class, 'getKullanici']);
    });
 
    Route::prefix("adres")->middleware('Admin')->group(function () {
        Route::get('/', [AdresController::class, 'getSehir'])->name("adres");
        Route::get('/ilce/{sehirId}',  [AdresController::class, 'getİlce'])->name("ilce");
        Route::get('/mahalle/{ilceId}',  [AdresController::class, 'getMahalle'])->name("mahalle");
        Route::post('/',  [AdresController::class, 'postSehir'])->name("adres");
        Route::post('/ilce/{sehirId}',  [AdresController::class, 'postİlce'])->name("ilce");
        Route::post('/mahalle/{ilceId}',  [AdresController::class, 'postMahalle'])->name("mahalle");

    });

    Route::prefix("menus")->middleware('Admin')->group(function () {
        Route::get('/',  [MenusController::class, 'getMenus'])->name("menus");
        Route::get('/menu-add',  [MenusController::class, 'getMenusAdd'])->name("menu-add");
        Route::get('/menu-edit/{menuId}',  [MenusController::class, 'getMenusEdit'])->name("menu-edit");
        Route::post('/',  [MenusController::class, 'postMenus'])->name("menus");
        Route::post('/menu-add',  [MenusController::class, 'postMenusAdd'])->name("menu-add");
        Route::post('/menu-edit/{menuId}',  [MenusController::class, 'postMenusEdit'])->name("menu-edit");

    });

    Route::prefix("siparis")->middleware('Admin')->group(function () {
        Route::get('/', [SiparisController::class, 'getSiparis'])->name("siparis");
        Route::get('/siparis-add', [SiparisController::class, 'getSiparisAdd'])->name("siparis-add");
        Route::get('/siparis-edit/{menuId}', [SiparisController::class, 'getSiparisEdit'])->name("siparis-edit");
        Route::post('/', [SiparisController::class, 'postSiparis'])->name("siparis");
        Route::post('/siparis-add', [SiparisController::class, 'postSiparisAdd'])->name("siparis-add");
        Route::post('/siparis-edit/{siparisId}', [SiparisController::class, 'postSiparisEdit'])->name("siparis-edit");
    });

    Route::prefix("pages")->middleware('Admin')->group(function () {
        Route::get('/',   [PagesController::class, 'getPages'])->name("pages");
        Route::get('/page-add',   [PagesController::class, 'getPagesAdd'])->name("page-add");
        Route::get('/page-edit/{pageId}',   [PagesController::class, 'getPagesEdit'])->name("page-edit");
        Route::post('/',   [PagesController::class, 'postPages'])->name("pages");
        Route::post('/page-add',   [PagesController::class, 'postPagesAdd'])->name("page-add");
        Route::post('/page-edit/{pageId}',   [PagesController::class, 'postPagesEdit'])->name("page-edit");
    });


    Route::prefix("sliders")->middleware('Admin')->group(function () {
        Route::get('/',   [SlidersController::class, 'getSliders'])->name("sliders");
        Route::get('/slider-add',   [SlidersController::class, 'getSlidersAdd'])->name("slider-add");
        Route::get('/slider-edit/{sliderId}',   [SlidersController::class, 'getSlidersEdit'])->name("slider-edit");
        Route::post('/',   [SlidersController::class, 'postSliders'])->name("sliders");
        Route::post('/slider-add',   [SlidersController::class, 'postSlidersAdd'])->name("slider-add");
        Route::post('/slider-edit/{sliderId}',   [SlidersController::class, 'postSlidersEdit'])->name("slider-edit");
      });

    Route::prefix("duyuru")->middleware('Admin')->group(function () {
        Route::get('/', [DuyuruController::class, 'getSliders'])->name("duyuru");
        Route::get('/duyuru-add', [DuyuruController::class, 'getSlidersAdd'])->name("duyuru-add");
        Route::get('/duyuru-edit/{duyuruId}', [DuyuruController::class, 'getSlidersEdit'])->name("duyuru-edit");
        Route::post('/', [DuyuruController::class, 'postSliders'])->name("duyuru");
        Route::post('/duyuru-add', [DuyuruController::class, 'postSlidersAdd'])->name("duyuru-add");
        Route::post('/duyuru-edit/{duyuruId}', [DuyuruController::class, 'postSlidersEdit'])->name("duyuru-edit");
 });

    Route::prefix("mail")->middleware('Admin')->group(function () {
        Route::get('/', [MailController::class, 'getMail'])->name("mail");
        Route::get('/mail-edit/{mailId}', [MailController::class, 'getMailEdit'])->name("mail-edit");
    });

    Route::prefix("users")->middleware('Admin')->group(function () {
        Route::get('/',  [UsersController::class, 'getUsers'])->name("users");
        Route::get('/user-add',  [UsersController::class, 'getUsersAdd'])->name("user-add");
        Route::get('/user-edit/{userId}',  [UsersController::class, 'getUsersEdit'])->name("user-edit");
        Route::post('/',  [UsersController::class, 'postUsers'])->name("users");
        Route::post('/user-add',  [UsersController::class, 'postUsersAdd'])->name("user-add");
        Route::post('/user-edit/{userId}',  [UsersController::class, 'postUsersEdit'])->name("user-edit");

    });

    Route::prefix("bayi")->middleware('Admin')->group(function () {
        Route::get('/', [BayiController::class, 'getUsers'])->name("bayi");
			Route::get('/bayi-add', [BayiController::class, 'getUsersAdd'])->name("bayi-add");
			Route::get('/bayi-edit/{bayiId}', [BayiController::class, 'getUsersEdit'])->name("bayi-edit");
			Route::post('/', [BayiController::class, 'postUsers'])->name("bayi");
			Route::post('/bayi-add', [BayiController::class, 'postUsersAdd'])->name("bayi-add");
			Route::post('/bayi-edit/{bayiId}', [BayiController::class, 'postUsersEdit'])->name("bayi-edit");});

    Route::prefix("customer")->middleware('Admin')->group(function () {
        Route::get('/',  [CustomerController::class, 'getUsers'])->name("customer");
        Route::get('/customer-add',  [CustomerController::class, 'getUsersAdd'])->name("customer-add");
        Route::get('/customer-edit/{customerId}',  [CustomerController::class, 'getUsersEdit'])->name("customer-edit");
        Route::post('/',  [CustomerController::class, 'postUsers'])->name("customer");
        Route::post('/customer-add',  [CustomerController::class, 'postUsersAdd'])->name("customer-add");
        Route::post('/customer-edit/{customerId}',  [CustomerController::class, 'postUsersEdit'])->name("customer-edit");
    });

    Route::prefix("settings")->middleware('Admin')->group(function () {
        Route::get('/', [SettingsController::class, 'getSettings'])->name("settings");
			Route::get('/setting-edit/{settingId}', [SettingsController::class, 'getSettingsEdit'])->name("setting-edit");
			Route::post('/', [SettingsController::class, 'postSettings'])->name("settings");
			Route::post('/setting-edit/{settingId}', [SettingsController::class, 'postSettingsEdit'])->name("setting-edit");

    });
	Route::post('/language-variable-update', [LanguageController::class, 'change_variable']);
	Route::post('/language-variable-insert', [LanguageController::class, 'insert_variable']);
	Route::resource('/languages', LanguageController::class);
});

// Frontend routes
Route::get('/quit', [FrontendBayiController::class, 'quit'])->name('quit');
Route::get('/test', function () {
    return view('test');
});

Route::prefix('{lang?}')->middleware(['test', 'Localization'])->group(function () {

    Route::prefix("/".trans('auth.arama'))->group(function () {
        Route::get('/{slug}', [SearchController::class, 'index'])->name('search');
    });

    Route::get('/', [HomeController::class, 'index'])->name('home');
    Route::get(trans('auth.giris'), [LoginController::class, 'login'])->name('girisyap');
    Route::get(trans('auth.kayit'), [LoginController::class, 'kayit'])->name('kayitol');
    Route::get(trans('auth.sifre'), [LoginController::class, 'sifre'])->name('sifreal');
    Route::get(trans('auth.sepet'), [FrontendBayiController::class, 'sepet'])->name('sepet');
    Route::get(trans('auth.teslimat adresi'), [FrontendBayiController::class, 'teslimatadresi'])->name('teslimat-adresi');
    Route::get(trans('auth.odeme'), [FrontendBayiController::class, 'odeme'])->name('odeme');
    Route::get(trans('auth.siparisozet'), [FrontendBayiController::class, 'siparisozet'])->name('siparis-ozet');
     Route::get(trans('auth.kampanya'), [SearchController::class, 'kampanya'])->name('kampanya');
    Route::get(trans('auth.yeni urun'), [SearchController::class, 'yeniurun'])->name('yeniurun');

    Route::prefix("/".trans('auth.bayi'))->middleware('bayii')->group(function () {
        Route::get(trans('auth.hesabim'), [FrontendBayiController::class, 'index'])->name('hesabim');
        Route::get(trans('auth.siparislerim'), [FrontendBayiController::class, 'siparis'])->name('siparislerim');
        Route::get(trans('auth.adres bilgilerim'), [FrontendBayiController::class, 'adreslist'])->name('adres-bilgilerim');
        Route::get(trans('auth.adres ekle'), [FrontendBayiController::class, 'getadres'])->name('adres-ekle');
        Route::get(trans('auth.adres').'/{adresid}', [FrontendBayiController::class, 'getadresduzenle'])->name('adres-duzenle');
        Route::get(trans('auth.favori'), [SearchController::class, 'favori'])->name('favori');
    });

   
  
    Route::get('{slug}', [ContentController::class, 'index']);
    Route::get('{kategori}/{slug}', [ContentController::class, 'kategori']);

    
   
});

// POST routes
Route::post('/yorum/{id}', [YorumController::class, 'yorum'])->name('yorum');
Route::post('/girisyap', [LoginController::class, 'postlogin'])->name('girisyappost');
Route::post('/kayitol', [LoginController::class, 'postkayit'])->name('sign');
Route::post('/sifreal', [LoginController::class, 'postsifre'])->name('sifrealpost');
Route::post('/hesabim', [FrontendBayiController::class, 'postindex'])->name('hesabimpost');
Route::post('/adres-ekle', [FrontendBayiController::class, 'postadres'])->name('adreseklepost');
Route::post('/adres/{adresid}', [FrontendBayiController::class, 'postadresduzenle'])->name('adresduzenlepost');
Route::post('favorite', [ContentController::class, 'favorite'])->name('favorite-add');
Route::post('{slug}', [ContentController::class, 'postindex'])->name('cart-add');